MicroPython Internals
=====================

This chapter covers a tour of MicroPython from the perspective of a developer, contributing
to MicroPython. It acts as a comprehensive resource on the implementation details of MicroPython
for both novice and expert contributors.

Development around MicroPython usually involves modifying the core runtime, porting or
maintaining a new library. This guide describes at great depth, the implementation
details of MicroPython including a getting started guide, compiler internals, porting
MicroPython to a new platform and implementing a core MicroPython library.

.. toctree::
   :maxdepth: 3

   gettingstarted.rst
   writingtests.rst
   compiler.rst
   memorymgt.rst
   library.rst
   optimizations.rst
   qstr.rst
   maps.rst
   publiccapi.rst
   extendingmicropython.rst
   porting.rst
